@@ -1,6 +1,11 @@
 import json
 import unittest
 
+try:
+    from unittest.mock import patch
+except ImportError:
+    from mock import patch
+
 import responses
 from requests import HTTPError
 
@@ -40,7 +45,8 @@ class BaseApiTest(unittest.TestCase):
         api = BaseApi(long_term_token="token", version="3.3")
         self.assertEqual(api.version, "v3.3")
 
-    def testApiToken(self):
+    @patch('time.sleep', return_value=None)
+    def testApiToken(self, patched_time_sleep):
         with self.assertRaises(pyfacebook.PyFacebookException):
             BaseApi()
 
